@@ -28,9 +28,10 @@
 #include <netdb.h>
 #include <arpa/inet.h>
 
-#include <asn1.h>
-#include <snmp.h>
-#include <snmp_impl.h>
+#include <net-snmp/net-snmp-config.h>
+#include <net-snmp/library/asn1.h>
+#include <net-snmp/library/snmp.h>
+#include <net-snmp/library/snmp_impl.h>
 #include <time.h>
 #include <ctype.h>
 
@@ -302,7 +303,7 @@ main(argc, argv)
 
   /* Init the logfile, non append mode, i.e. create a new one */
   loginit(PNAME, LOGFILE, o_loglev, 0);
-  log(1, "Starting ...");
+  logging(1, "Starting ...");
 
   /* Parse the configuration file */
   o_logfile = lg_parse_config(o_cfgname);
@@ -314,10 +315,10 @@ main(argc, argv)
   }
 
   /* Create and open the pipe */
-  log(1, "Create the pipe '%s' ...", PIPENAME);
+  logging(1, "Create the pipe '%s' ...", PIPENAME);
   if ((mkfifo(PIPENAME, S_IWUSR | S_IRUSR) == -1) && (errno != EEXIST))
   {
-    log(0, "Cannot create the pipe '%s' [%s]", PIPENAME, strerror(errno));
+    logging(0, "Cannot create the pipe '%s' [%s]", PIPENAME, strerror(errno));
 
     exit(1);
   }
@@ -325,7 +326,7 @@ main(argc, argv)
   fd_pipe = open(PIPENAME, O_RDWR, S_IWUSR | S_IRUSR);
   if (fd_pipe < 0)
   {
-    log(0, "Cannot open the pipe '%s' [%s]", PIPENAME, strerror(errno));
+    logging(0, "Cannot open the pipe '%s' [%s]", PIPENAME, strerror(errno));
 
     exit(1);
   }
@@ -333,12 +334,12 @@ main(argc, argv)
   f_pipe = fdopen(fd_pipe, "w+");
   if (f_pipe == NULL)
   {
-    log(0, "Cannot associate stream with file handle for pipe '%s' [%s]",
+    logging(0, "Cannot associate stream with file handle for pipe '%s' [%s]",
         PIPENAME, strerror(errno));
 
     exit(1);
   }
-  log(1, "Pipe opened for reading");
+  logging(1, "Pipe opened for reading");
 
   /* Main loop: sit and wait until data arrives on the pipe */
   while (1)
@@ -352,22 +353,22 @@ main(argc, argv)
     switch (numfds)
     {
       case 0:
-        log(1, "Timeout occurred ...");
+        logging(1, "Timeout occurred ...");
         break;
       case -1:
         if (errno == EINTR)
         {
-          log(1, "Interrupted select() - continue");
+          logging(1, "Interrupted select() - continue");
           continue;
         }
         else
         {
-          log(0, "Error from select() [%s]", strerror(errno));
+          logging(0, "Error from select() [%s]", strerror(errno));
           exit(1);
         }
         break;
       default:
-        log(1, "Data available ...");
+        logging(1, "Data available ...");
         process_trapdata(f_pipe);
         break;
     }
@@ -418,11 +419,11 @@ lg_parse_config(cfgname)
   int             lno = 0;
 
 
-  log(1, "Parsing config file '%s'", cfgname);
+  logging(1, "Parsing config file '%s'", cfgname);
 
   if (!(cfg = fopen(cfgname, "r")))
   {
-    log(0, "Cannot open config file '%s' - %s\n", cfgname, strerror(errno));
+    logging(0, "Cannot open config file '%s' - %s\n", cfgname, strerror(errno));
 
     return NULL;
   }
@@ -431,7 +432,7 @@ lg_parse_config(cfgname)
   {
     char           *p;
 
-    log(1, "Read line '%s'", lbuf);
+    logging(1, "Read line '%s'", lbuf);
 
     p = strtok(lbuf, "=\n");
 
@@ -468,7 +469,7 @@ lg_parse_config(cfgname)
       }
       if (!ok)
       {
-        log(0, "Expected: %s=\\<char>\\<char>\\ in file '%s',%d",
+        logging(0, "Expected: %s=\\<char>\\<char>\\ in file '%s',%d",
             TOK_SUBST, cfgname, lno);
       }
     }
@@ -486,7 +487,7 @@ lg_parse_config(cfgname)
 #if 0
         cfg_oidfmt = OIDFMT_TEXT;
 #else
-        log(0, "Error: Format for OID must be set in /etc/snmp/snmp.conf");
+        logging(0, "Error: Format for OID must be set in /etc/snmp/snmp.conf");
 
         cfg_oidfmt = OIDFMT_OID;
 #endif
@@ -501,7 +502,7 @@ lg_parse_config(cfgname)
       }
       if (!ok)
       {
-        log(0, "Expected: %s='text' | 'oid' in file '%s',%d",
+        logging(0, "Expected: %s='text' | 'oid' in file '%s',%d",
             TOK_OIDFMT, cfgname, lno);
       }
     }
@@ -532,7 +533,7 @@ lg_parse_config(cfgname)
       }
       if (!ok)
       {
-        log(0, "Expected: %s='ip' | 'fqdn' | 'name' in file '%s',%d",
+        logging(0, "Expected: %s='ip' | 'fqdn' | 'name' in file '%s',%d",
             TOK_NODEFMT, cfgname, lno);
       }
     }
@@ -573,7 +574,7 @@ lg_parse_config(cfgname)
           }
           else if (strcasecmp(TOK_CMUSNMP, p) == 0)
           {
-            log(0, "The option 'CMUSNMP' is obsolete");
+            logging(0, "The option 'CMUSNMP' is obsolete");
           }
         }
         else
@@ -587,12 +588,12 @@ lg_parse_config(cfgname)
       }
       if (!ok)
       {
-        log(0, "Expected: %s=\"<string>\" in file '%s',%d", p, cfgname, lno);
+        logging(0, "Expected: %s=\"<string>\" in file '%s',%d", p, cfgname, lno);
       }
     }
     else
     {
-      log(0, "Missing token in file '%s',%d", cfgname, lno);
+      logging(0, "Missing token in file '%s',%d", cfgname, lno);
     }
   }
 
@@ -605,7 +606,7 @@ lg_parse_config(cfgname)
 
     if (!f_log)
     {
-      log(0, "Cannot append to logfile '%s' [%s]",
+      logging(0, "Cannot append to logfile '%s' [%s]",
           cfg_logname, strerror(errno));
     }
   }
@@ -629,14 +630,14 @@ lg_print_config()
   nodefmt[NODEFMT_FQDN] = "fqdn";
   nodefmt[NODEFMT_NAME] = "name";
 
-  log(1, "Configuration variables:");
-  log(1, " cfg_subst1  = '%c'", cfg_subst1);
-  log(1, " cfg_subst2  = '%c'", cfg_subst2);
-  log(1, " cfg_oidfmt  = %s", oidfmt[cfg_oidfmt]);
-  log(1, " cfg_nodefmt = %s", nodefmt[cfg_nodefmt]);
-  log(1, " cfg_varfmt  = \"%s\"", cfg_varfmt);
-  log(1, " cfg_logfmt  = \"%s\"", cfg_logfmt);
-  log(1, " cfg_logname = \"%s\"",
+  logging(1, "Configuration variables:");
+  logging(1, " cfg_subst1  = '%c'", cfg_subst1);
+  logging(1, " cfg_subst2  = '%c'", cfg_subst2);
+  logging(1, " cfg_oidfmt  = %s", oidfmt[cfg_oidfmt]);
+  logging(1, " cfg_nodefmt = %s", nodefmt[cfg_nodefmt]);
+  logging(1, " cfg_varfmt  = \"%s\"", cfg_varfmt);
+  logging(1, " cfg_logfmt  = \"%s\"", cfg_logfmt);
+  logging(1, " cfg_logname = \"%s\"",
       (cfg_logname && *cfg_logname ? cfg_logname : "<syslog>"));
 }
 
@@ -656,7 +657,7 @@ lg_format_buffer(t_trap * p_trap, time_t trap_time)
   int             seqno;        /* sequence number of variable */
 
 
-  log(1, "Formatting the trap data with '%s' ...", cfg_logfmt);
+  logging(1, "Formatting the trap data with '%s' ...", cfg_logfmt);
 
   /* init */
   bRem = sizeof(buf) - 1;       /* leave space for EOS */
@@ -751,14 +752,14 @@ lg_format_buffer(t_trap * p_trap, time_t trap_time)
     /* leave if no more space is left */
     if (bRem == 0)
     {
-      log(0, "No more internal space left for remaining format '%s'", lPtr);
+      logging(0, "No more internal space left for remaining format '%s'", lPtr);
       break;
     }
   }
   *cPtr = '\0';
 
   /* Debug output  */
-  log(1, "Output buffer: '%s'", buf);
+  logging(1, "Output buffer: '%s'", buf);
 
   /* this is the result */
   return buf;
@@ -781,7 +782,7 @@ lg_sprint_node(name, nodeFmt, cPPtr, bRemP)
   int             l;
   struct hostent *hent = gethostbyname(name);
 
-  log(1, "lg_sprint_node(%s, ...)", name);
+  logging(1, "lg_sprint_node(%s, ...)", name);
 
   switch (nodeFmt)
   {
@@ -834,7 +835,7 @@ lg_sprint_node(name, nodeFmt, cPPtr, bRemP)
   }
   else
   {
-    log(0, "No more internal space left for '%s'", lbuf);
+    logging(0, "No more internal space left for '%s'", lbuf);
   }
 }
 
@@ -852,16 +853,16 @@ lg_sprint_oid(oidP, oidFmt, cPPtr, bRemP)
   char            lbuf[1024];   /* local buffer */
   int             l;
 
-  log(1, "lg_sprint_oid(%s, ...)", oidP);
+  logging(1, "lg_sprint_oid(%s, ...)", oidP);
 
   switch (oidFmt)
   {
     case OIDFMT_TEXT:          /* use textual format for the oid */
-      sprintf(lbuf, "%s", oidP);
+      sprintf(lbuf, "%s", oidP ? oidP : "(null)");
       break;
     case OIDFMT_OID:           /* usenumerical format for the oid */
     default:                   /* shouldn't happen */
-      sprintf(lbuf, "%s", oidP);
+      sprintf(lbuf, "%s", oidP ? oidP : "(null)");
       break;
   }
 
@@ -875,7 +876,7 @@ lg_sprint_oid(oidP, oidFmt, cPPtr, bRemP)
   }
   else
   {
-    log(0, "No more internal space left for '%s'", lbuf);
+    logging(0, "No more internal space left for '%s'", lbuf);
   }
 }
 
@@ -891,7 +892,7 @@ lg_sprint_string(stringP, cPPtr, bRemP)
 {
   int             l;
 
-  log(1, "lg_sprint_string(%s, ...)", stringP);
+  logging(1, "lg_sprint_string(%s, ...)", stringP);
 
   /* insert the string into the output buffer */
   l = strlen(stringP);
@@ -903,7 +904,7 @@ lg_sprint_string(stringP, cPPtr, bRemP)
   }
   else
   {
-    log(0, "No more internal space left for '%s'", stringP);
+    logging(0, "No more internal space left for '%s'", stringP);
   }
 }
 
@@ -921,7 +922,7 @@ lg_sprint_int(ival, iFmt, cPPtr, bRemP)
   char            lbuf[20];     /* local buffer */
   int             l;
 
-  log(1, "lg_spring_int(%d, ...)", ival);
+  logging(1, "lg_spring_int(%d, ...)", ival);
 
   /* fill the local buffer */
   sprintf(lbuf, iFmt, ival);
@@ -936,7 +937,7 @@ lg_sprint_int(ival, iFmt, cPPtr, bRemP)
   }
   else
   {
-    log(0, "No more internal space left for '%s'", lbuf);
+    logging(0, "No more internal space left for '%s'", lbuf);
   }
 }
 
@@ -954,7 +955,7 @@ lg_sprint_ulong(uval, uFmt, cPPtr, bRemP)
   char            lbuf[20];     /* local buffer */
   int             l;
 
-  log(1, "lg_sprint_ulong(%lu, ...)", uval);
+  logging(1, "lg_sprint_ulong(%lu, ...)", uval);
 
   /* fill the local buffer */
   sprintf(lbuf, uFmt, uval);
@@ -969,7 +970,7 @@ lg_sprint_ulong(uval, uFmt, cPPtr, bRemP)
   }
   else
   {
-    log(0, "No more internal space left for '%s'", lbuf);
+    logging(0, "No more internal space left for '%s'", lbuf);
   }
 }
 
@@ -986,7 +987,7 @@ lg_sprint_ASNtype(asntype, cPPtr, bRemP)
   char           *p;
   int             l;
 
-  log(1, "lg_sprint_ASNtype(%c, ...)", asntype);
+  logging(1, "lg_sprint_ASNtype(%c, ...)", asntype);
 
   switch (asntype)
   {
@@ -1041,7 +1042,7 @@ lg_sprint_ASNtype(asntype, cPPtr, bRemP)
   }
   else
   {
-    log(0, "No more internal space left for '%s'", p);
+    logging(0, "No more internal space left for '%s'", p);
   }
 
   /* temporary close the string  */
@@ -1063,7 +1064,7 @@ lg_sprint_var(var, vFmt, seqno, cPPtr, bRemP)
 {
   char           *vPtr;         /* current varfmt character */
 
-  log(1, "lg_sprint_var(%s/%s, %s, %d, ...)",
+  logging(1, "lg_sprint_var(%s/%s, %s, %d, ...)",
       var->v_oid, var->v_val, vFmt, seqno);
 
   /* process the variable format */
@@ -1104,7 +1105,7 @@ lg_sprint_var(var, vFmt, seqno, cPPtr, bRemP)
             lg_sprint_oid(var->v_oid, cfg_oidfmt, cPPtr, bRemP);
             break;
           case 't':            /* the type */
-            log(0, "Type info not available - using ASN_OCTET_STR");
+            logging(1, "Type info not available - using ASN_OCTET_STR");
             lg_sprint_ASNtype(ASN_OCTET_STR, cPPtr, bRemP);
             break;
           case 'v':            /* the value */
@@ -1171,7 +1172,7 @@ lg_sprint_var(var, vFmt, seqno, cPPtr, bRemP)
 
     if (*bRemP <= 0)
     {
-      log(0, "No more internal space left for variable %d", seqno);
+      logging(0, "No more internal space left for variable %d", seqno);
       *bRemP = 0;
       break;
     }
@@ -1195,28 +1196,28 @@ read_trapdata(FILE * f, t_trap * p_trap)
   {
     return -1;
   }
-  log(1, "Store: AGENTNAME := '%s'", p_trap->s_agentname);
+  logging(1, "Store: AGENTNAME := '%s'", p_trap->s_agentname);
 
   if (read_oidval(f, &p_trap->s_senderaddr, NULL,
                   "Missing SENDERIP from handler") == -1)
   {
     return -1;
   }
-  log(1, "Store: SENDERADDR := '%s'", p_trap->s_senderaddr);
+  logging(1, "Store: SENDERADDR := '%s'", p_trap->s_senderaddr);
 
   if (read_oidval(f, NULL, &p_trap->s_uptime,
                   "Missing UPTIME from handler") == -1)
   {
     return -1;
   }
-  log(1, "Store: UPTIME := '%s'", p_trap->s_uptime);
+  logging(1, "Store: UPTIME := '%s'", p_trap->s_uptime);
 
   if (read_oidval(f, NULL, &p_trap->s_trapoid,
                   "Missing TRAPOID from handler") == -1)
   {
     return -1;
   }
-  log(1, "Store: TRAPOID := '%s'", p_trap->s_trapoid);
+  logging(1, "Store: TRAPOID := '%s'", p_trap->s_trapoid);
 
   /* Now read all remaining OID/VAL pairs */
   while (read_oidval(f, &oid, &val, NULL) == 0)
@@ -1224,7 +1225,7 @@ read_trapdata(FILE * f, t_trap * p_trap)
     if (oid[0] == '\0')
     {
       /* End of data from handler */
-      log(1, "End of handler data reached");
+      logging(1, "End of handler data reached");
       free(oid);
       free(val);
       break;
@@ -1234,21 +1235,21 @@ read_trapdata(FILE * f, t_trap * p_trap)
     {
       free(oid);
       p_trap->s_agentaddr = val;
-      log(1, "Store: SNMPTRAPADDRESS := '%s'", p_trap->s_agentaddr);
+      logging(1, "Store: SNMPTRAPADDRESS := '%s'", p_trap->s_agentaddr);
     }
     else if ((strcmp(oid, OID_SYM_SNMPTRAPCOMMUNITY) == 0) ||
              (strcmp(oid, OID_NUM_SNMPTRAPCOMMUNITY) == 0))
     {
       free(oid);
       p_trap->s_community = val;
-      log(1, "Store: SNMPTRAPCOMMUNITY := '%s'", p_trap->s_community);
+      logging(1, "Store: SNMPTRAPCOMMUNITY := '%s'", p_trap->s_community);
     }
     else if ((strcmp(oid, OID_SYM_SNMPTRAPENTERPRISE) == 0) ||
              (strcmp(oid, OID_NUM_SNMPTRAPENTERPRISE) == 0))
     {
       free(oid);
       p_trap->s_enterprise = val;
-      log(1, "Store: SNMPTRAPENTERPRISE := '%s'", p_trap->s_enterprise);
+      logging(1, "Store: SNMPTRAPENTERPRISE := '%s'", p_trap->s_enterprise);
     }
     else
     {
@@ -1259,7 +1260,7 @@ read_trapdata(FILE * f, t_trap * p_trap)
       p = realloc(p_trap->a_var, p_trap->n_var * sizeof(t_var));
       if (p == NULL)
       {
-        log(0, "Out of memory - aborting");
+        logging(0, "Out of memory - aborting");
         exit(1);
       }
       p_trap->a_var = p;
@@ -1267,7 +1268,7 @@ read_trapdata(FILE * f, t_trap * p_trap)
       p_trap->a_var[p_trap->n_var - 1].v_oid = oid;
       p_trap->a_var[p_trap->n_var - 1].v_val = val;
 
-      log(1, "Store var %d: '%s' := '%s'", p_trap->n_var, oid, val);
+      logging(1, "Store var %d: '%s' := '%s'", p_trap->n_var, oid, val);
     }
   }
 
@@ -1290,7 +1291,7 @@ process_trapdata(FILE * f)
 
   if (read_trapdata(f, &trapdata) == -1)
   {
-    log(0, "Error reading trap data - skip formatting");
+    logging(0, "Error reading trap data - skip formatting");
     free_trap(&trapdata);
 
     return;
@@ -1302,18 +1303,18 @@ process_trapdata(FILE * f)
   /* And now log the data according to the configuration */
   if (!buf)
   {
-    log(0, "Error: Cannot allocate/format output buffer");
+    logging(0, "Error: Cannot allocate/format output buffer");
   }
   else if (o_logfile)
   {
-    log(1, "Logging to file '%s'", buf);
+    logging(1, "Logging to file '%s'", buf);
 
     fprintf(o_logfile, "%s\n", buf);
     fflush(o_logfile);
   }
   else
   {
-    log(1, "Logging to syslog 'LOG_WARNING:%s'", buf);
+    logging(1, "Logging to syslog 'LOG_WARNING:%s'", buf);
 
     syslog(LOG_WARNING, "%s\n", buf);
   }
@@ -1336,7 +1337,7 @@ read_oidval(FILE * f, char **pp_oid, char **pp_val, char *msg)
   {
     if (msg)
     {
-      log(0, msg);
+      logging(0, msg);
     }
 
     return -1;
@@ -1354,7 +1355,7 @@ read_oidval(FILE * f, char **pp_oid, char **pp_val, char *msg)
       rbuf[l - 1] = '\0';
     }
 
-    log(1, "Read from handler: '%s'", rbuf);
+    logging(1, "Read from handler: '%s'", rbuf);
 
     /* split the line (if two components are on the line) */
     p_del = strchr(rbuf, ' ');
@@ -1375,7 +1376,7 @@ read_oidval(FILE * f, char **pp_oid, char **pp_val, char *msg)
       *pp_val = copy_string(p_del ? p_del + 1 : rbuf);
     }
 
-    log(1, " Split: OID = '%s', VAL = '%s'", rbuf,
+    logging(1, " Split: OID = '%s', VAL = '%s'", rbuf,
         (p_del ? p_del + 1 : rbuf));
   }
 
@@ -1400,7 +1401,7 @@ copy_string(char *buf)
   s = strdup(buf);
   if (s == NULL)
   {
-    log(0, "Out of memory - aborting");
+    logging(0, "Out of memory - aborting");
     exit(1);
   }
 
