@@ -50,7 +50,7 @@ main (int argc, char **argv)
 
   /* Init log file handling, append mode is on */
   loginit (PNAME, LOGFILE, o_loglev, 1);
-  log (1, "Traphandler started ...");
+  logging (1, "Traphandler started ...");
 
   /*
    * Check if the named pipe exists and a reader has opened. 
@@ -60,21 +60,21 @@ main (int argc, char **argv)
   fd = open (PIPENAME, O_WRONLY | O_NONBLOCK);
   if (fd == -1)
   {
-    log (0, "Error opening pipe '%s' [%s]", PIPENAME, strerror (errno));
+    logging (0, "Error opening pipe '%s' [%s]", PIPENAME, strerror (errno));
     exit (1);
   }
-  log (1, "Opened pipe '%s'", PIPENAME);
+  logging (1, "Opened pipe '%s'", PIPENAME);
 
   /*
    * Read all data from stdin and forward to the pipe
    */
   while ((rcnt = read (0, inbuf, sizeof (inbuf))) > 0)
   {
-    log (1, "Read line from stdin: '%s'", inbuf);
+    logging (1, "Read line from stdin: '%s'", inbuf);
 
     if (rcnt != write (fd, inbuf, rcnt))
     {
-      log (0, "Error writing to pipe '%s' [%s]", PIPENAME, strerror (errno));
+      logging (0, "Error writing to pipe '%s' [%s]", PIPENAME, strerror (errno));
       close (fd);
 
       exit (1);
@@ -82,22 +82,22 @@ main (int argc, char **argv)
   }
   if (write (fd, "\n", 1) != 1)
   {
-    log (0, "Error writing EOD to pipe '%s' [%s]",
+    logging (0, "Error writing EOD to pipe '%s' [%s]",
          PIPENAME, strerror (errno));
     close (fd);
 
     exit (1);
   }
-  log (1, "Wrote EOD to pipe");
+  logging (1, "Wrote EOD to pipe");
 
   if (rcnt < 0)
   {
-    log (0, "Error reading from stdin [%s]", strerror (errno));
+    logging (0, "Error reading from stdin [%s]", strerror (errno));
   }
 
   close (fd);
 
-  log (1, "Traphandler terminated.");
+  logging (1, "Traphandler terminated.");
 
   return (rcnt == 0 ? 0 : 1);
 }
